pub enum EvaluateUnlocked {
Normal,
FingerprintableDeterministic {
block_number: usize,
},
}Expand description
How to evaluate if an output is unlocked.
Variants
Normal
The normal method of evaluation.
FingerprintableDeterministic
A deterministic method which only considers the view of the blockchain as of block
#block_number. This is fingerprintable as outputs locked with a time-based timelock will
always be considered locked and never be selected as decoys.