pub struct PrunedTransactionWithPrunableHash { /* private fields */ }Expand description
A pruned transaction with the hash of its pruned data, if version != 1.
Implementations
Sourceimpl PrunedTransactionWithPrunableHash
impl PrunedTransactionWithPrunableHash
Sourcepub fn new(
transaction: Transaction<Pruned>,
prunable_hash: Option<[u8; 32]>,
) -> Option<Self>
pub fn new( transaction: Transaction<Pruned>, prunable_hash: Option<[u8; 32]>, ) -> Option<Self>
Create a new PrunedTransactionWithPrunableHash.
This expects (version != 1) == (prunable_hash = Some(_)) and returns None otherwise.
Sourcepub fn verify_as_possible(
self,
hash: [u8; 32],
) -> Result<Transaction<Pruned>, [u8; 32]>
pub fn verify_as_possible( self, hash: [u8; 32], ) -> Result<Transaction<Pruned>, [u8; 32]>
Verify the transaction has the expected hash, if possible.
This only works for transaction where version != 1. Transactions where version = 1 will
be returned without any verification.
If verification fails, the actual hash of the transaction is returned as the error.