RingCtOutputInformation

Struct RingCtOutputInformation 

pub struct RingCtOutputInformation {
    pub block_number: usize,
    pub unlocked: bool,
    pub key: CompressedPoint,
    pub commitment: Point,
    pub transaction: [u8; 32],
}
The response to an query for the information of a RingCT output.

Fields

block_number: usize

The block number of the block this output was added to the chain in.

unlocked: bool

If the output is unlocked, per the node’s local view.

key: CompressedPoint

The output’s key.

This is a CompressedPoint, not an Point, as it may be invalid. CompressedPoint only asserts validity on decompression and allows representing invalid points.

commitment: Point

The output’s commitment.

transaction: [u8; 32]

The transaction which created this output.