ScannableBlock

Struct ScannableBlock 

pub struct ScannableBlock {
    pub block: Block,
    pub transactions: Vec<Transaction<Pruned>>,
    pub output_index_for_first_ringct_output: Option<u64>,
}
A block which is able to be scanned.

As this struct’s fields are public, no internal consistency is enforced.

Fields

block: Block

The block which is scannable.

transactions: Vec<Transaction<Pruned>>

The non-miner transactions within this block.

output_index_for_first_ringct_output: Option<u64>

The output index for the first RingCT output within this block.

This should be None if there are no RingCT outputs within this block, Some otherwise.

This is not bound to be correct by any of the functions within this crate’s API as it’s infeasible to verify the accuracy of. To do so would require a trusted view over the RingCT outputs, synchronized to the block before this. To ensure correctness and privacy, the user SHOULD locally maintain a database of the RingCT outputs and the user SHOULD use it to override whatever is claimed to be the output index for the first RingCT output within this block. If the values are different, the user SHOULD detect the interface is invalid and disconnect entirely.